summaryrefslogtreecommitdiffstats
path: root/lib_microblaze
diff options
context:
space:
mode:
Diffstat (limited to 'lib_microblaze')
-rw-r--r--lib_microblaze/board.c30
-rw-r--r--lib_microblaze/bootm.c5
-rw-r--r--lib_microblaze/time.c2
3 files changed, 21 insertions, 16 deletions
diff --git a/lib_microblaze/bootm.c b/lib_microblaze/bootm.c
index 5986a31cc8..e97aae6881 100644
--- a/lib_microblaze/bootm.c
+++ b/lib_microblaze/bootm.c
@@ -38,6 +38,9 @@ int do_bootm_linux(int flag, int argc, char *argv[], bootm_headers_t *images)
void (*theKernel) (char *);
char *commandline = getenv ("bootargs");
+ if ((flag != 0) && (flag != BOOTM_STATE_OS_GO))
+ return 1;
+
theKernel = (void (*)(char *))images->ep;
show_boot_progress (15);
@@ -49,6 +52,6 @@ int do_bootm_linux(int flag, int argc, char *argv[], bootm_headers_t *images)
theKernel (commandline);
/* does not return */
-error:
+
return 1;
}
diff --git a/lib_microblaze/time.c b/lib_microblaze/time.c
index b5d8f19379..cbb43414f9 100644
--- a/lib_microblaze/time.c
+++ b/lib_microblaze/time.c
@@ -26,7 +26,7 @@
#include <common.h>
-#ifdef CFG_TIMER_0
+#ifdef CONFIG_SYS_TIMER_0
void udelay (unsigned long usec)
{
int i;
OpenPOWER on IntegriCloud
diff --git a/lib_microblaze/board.c b/lib_microblaze/board.c
index 09d4d943de..4f48341f33 100644
--- a/lib_microblaze/board.c
+++ b/lib_microblaze/board.c
@@ -27,17 +27,18 @@
#include <common.h>
#include <command.h>
#include <malloc.h>
+#include <timestamp.h>
#include <version.h>
#include <watchdog.h>
DECLARE_GLOBAL_DATA_PTR;
-const char version_string[] = U_BOOT_VERSION " (" __DATE__ " - " __TIME__ ")";
+const char version_string[] = U_BOOT_VERSION " ("U_BOOT_DATE" - "U_BOOT_TIME")";
-#ifdef CFG_GPIO_0
+#ifdef CONFIG_SYS_GPIO_0
extern int gpio_init (void);
#endif
-#ifdef CFG_INTC_0
+#ifdef CONFIG_SYS_INTC_0
extern int interrupts_init (void);
#endif
#if defined(CONFIG_CMD_NET)
@@ -54,13 +55,13 @@ static ulong mem_malloc_brk;
/*
* The Malloc area is immediately below the monitor copy in DRAM
* aka CFG_MONITOR_BASE - Note there is no need for reloc_off
* as our monitory code is run from SDRAM
*/
static void mem_malloc_init (void)
{
- mem_malloc_end = (CFG_MALLOC_BASE + CFG_MALLOC_LEN);
- mem_malloc_start = CFG_MALLOC_BASE;
+ mem_malloc_end = (CONFIG_SYS_MALLOC_BASE + CONFIG_SYS_MALLOC_LEN);
+ mem_malloc_start = CONFIG_SYS_MALLOC_BASE;
mem_malloc_brk = mem_malloc_start;
memset ((void *)mem_malloc_start, 0, mem_malloc_end - mem_malloc_start);
}
@@ -94,10 +95,10 @@ typedef int (init_fnc_t) (void);
init_fnc_t *init_sequence[] = {
env_init,
serial_init,
-#ifdef CFG_GPIO_0
+#ifdef CONFIG_SYS_GPIO_0
gpio_init,
#endif
-#ifdef CFG_INTC_0
+#ifdef CONFIG_SYS_INTC_0
interrupts_init,
#endif
NULL,
@@ -107,18 +108,19 @@ void board_init (void)
{
bd_t *bd;
init_fnc_t **init_fnc_ptr;
- gd = (gd_t *) CFG_GBL_DATA_OFFSET;
+ gd = (gd_t *) CONFIG_SYS_GBL_DATA_OFFSET;
#if defined(CONFIG_CMD_FLASH)
ulong flash_size = 0;
#endif
asm ("nop"); /* FIXME gd is not initialize - wait */
- memset ((void *)gd, 0, CFG_GBL_DATA_SIZE);
+ memset ((void *)gd, 0, CONFIG_SYS_GBL_DATA_SIZE);
gd->bd = (bd_t *) (gd + 1); /* At end of global data */
gd->baudrate = CONFIG_BAUDRATE;
bd = gd->bd;
bd->bi_baudrate = CONFIG_BAUDRATE;
- bd->bi_memstart = CFG_SDRAM_BASE;
- bd->bi_memsize = CFG_SDRAM_SIZE;
+ bd->bi_memstart = CONFIG_SYS_SDRAM_BASE;
+ bd->bi_memsize = CONFIG_SYS_SDRAM_SIZE;
+ gd->flags |= GD_FLG_RELOC; /* tell others: relocation done */
/* Initialise malloc() area */
mem_malloc_init ();
@@ -131,10 +133,10 @@ void board_init (void)
}
#if defined(CONFIG_CMD_FLASH)
- bd->bi_flashstart = CFG_FLASH_BASE;
+ bd->bi_flashstart = CONFIG_SYS_FLASH_BASE;
if (0 < (flash_size = flash_init ())) {
bd->bi_flashsize = flash_size;
- bd->bi_flashoffset = CFG_FLASH_BASE + flash_size;
+ bd->bi_flashoffset = CONFIG_SYS_FLASH_BASE + flash_size;
} else {
puts ("Flash init FAILED");
bd->bi_flashstart = 0;
@@ -54,13 +55,13 @@ static ulong mem_malloc_brk;
/*
* The Malloc area is immediately below the monitor copy in DRAM
- * aka CFG_MONITOR_BASE - Note there is no need for reloc_off
+ * aka CONFIG_SYS_MONITOR_BASE - Note there is no need for reloc_off
* as our monitory code is run from SDRAM
*/